---
title: Shopify 플러그인
description: Shopify 플러그인을 통해 포트원을 사용하는 방법을 안내합니다.
targetVersions:
  - v1
---

<div class="hint" data-style="info">

이 가이드에서는 Shopify에서 PortOne을 통해 다양한 결제수단을 지원하는
플러그인의 사용법을 설명합니다. 쇼피파이 플러그인을 통하여 국내PG사와 해외PSP 이용이 가능한데,
해외PSP만 이용하신 다면 글로벌 플랫폼만 이용하시면 되고, 국내PG사까지 연동하시려면 [PortOne
한국 플랫폼](https://portone.io/korea/ko)과 [PortOne 글로벌
플랫폼](https://portone.io/global/en)을 모두 사용해야 합니다.
본 서비스는 서비스 이용 계약서 작성 후 이용이 가능하오니
[쇼피파이 이용 안내 가이드](https://help.portone.io/content/shopify-guide)를 참고 부탁드리며
플러그인 연동은 [쇼피파이 연동 가이드](https://docs-global-kr.portone.cloud/product/shopify/overview)를 참고해 주세요.

</div>

## 포트원의 Shopify plugin을 통해 이용하실 수 있는 국내PG사와 결제 수단은 아래와 같습니다.

|PG사         |지역  |타입    |결제수단            |
|-------------|------|--------|--------------------|
|KAKAOPAY     |Korea |간편결제|일체                |
|PAYCO        |Korea |간편결제|일체                |
|TOSSPAY      |Korea |간편결제|일체                |
|KG INICIS    |Korea |PG      |카드결제            |
|KG INICIS    |Korea |PG      |NAVERPAY(허브형)    |
|KG INICIS    |Korea |PG      |KAKAOPAY(허브형)    |
|KG INICIS    |Korea |PG      |PAYCO(허브형)       |
|KG INICIS    |Korea |PG      |TOSSPAY(허브형)     |
|NHN KCP      |Korea |PG      |카드결제            |
|NHN KCP      |Korea |PG      |NAVERPAY(허브형)    |
|NHN KCP      |Korea |PG      |KAKAOPAY(허브형)    |
|TOSS PAYMENTS|Korea |PG      |카드결제            |
|TOSS PAYMENTS|Korea |PG      |NAVERPAY(허브형)    |
|TOSS PAYMENTS|Korea |PG      |KAKAOPAY(허브형)    |
|TOSS PAYMENTS|Korea |PG      |계좌이체            |
|NICE PAYMENTS|Korea |PG      |카드결제            |
|NICE PAYMENTS|Korea |PG      |NAVERPAY(허브형)    |
|NICE PAYMENTS|Korea |PG      |KAKAOPAY(허브형)    |
|PAYMENTWALL  |Global|PG      |카드결제            |
|PAYMENTWALL  |Global|PG      |간편결제            |
|EXIMBAY      |Global|PG      |카드결제            |
|EXIMBAY      |Global|PG      |Alipay+             |
|EXIMBAY      |Global|PG      |WeChatPay           |
|EXIMBAY      |Global|PG      |UnionPay            |
|EXIMBAY      |Japan |PG      |eContext(편의점결제)|
|PAYLETTER    |Global|PG      |카드결제            |

## 글로벌 포트원에서 지원하는 해외PSP 목록은 아래 링크에서 문서 목록을 참고해 주세요.

<https://docs.portone.cloud/docs/payment-channels>
